package com.ruoyi.basetyre.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.basetyre.domain.BaseTyre;
import com.ruoyi.basetyre.service.IBaseTyreService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 轮胎Controller
 * 
 * @author Yangwl
 * @date 2023-02-15
 */
@RestController
@RequestMapping("/basetyre/tyre")
public class BaseTyreController extends BaseController
{
    @Autowired
    private IBaseTyreService baseTyreService;

    /**
     * 查询轮胎列表
     */
    @PreAuthorize("@ss.hasPermi('basetyre:tyre:list')")
    @GetMapping("/list")
    public TableDataInfo list(BaseTyre baseTyre)
    {
        startPage();
        List<BaseTyre> list = baseTyreService.selectBaseTyreList(baseTyre);
        return getDataTable(list);
    }

    /**
     * 导出轮胎列表
     */
    @PreAuthorize("@ss.hasPermi('basetyre:tyre:export')")
    @Log(title = "轮胎", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BaseTyre baseTyre)
    {
        List<BaseTyre> list = baseTyreService.selectBaseTyreList(baseTyre);
        ExcelUtil<BaseTyre> util = new ExcelUtil<BaseTyre>(BaseTyre.class);
        util.exportExcel(response, list, "轮胎数据");
    }

    /**
     * 获取轮胎详细信息
     */
    @PreAuthorize("@ss.hasPermi('basetyre:tyre:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return success(baseTyreService.selectBaseTyreById(id));
    }

    /**
     * 新增轮胎
     */
    @PreAuthorize("@ss.hasPermi('basetyre:tyre:add')")
    @Log(title = "轮胎", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BaseTyre baseTyre)
    {
        return toAjax(baseTyreService.insertBaseTyre(baseTyre));
    }

    /**
     * 修改轮胎
     */
    @PreAuthorize("@ss.hasPermi('basetyre:tyre:edit')")
    @Log(title = "轮胎", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BaseTyre baseTyre)
    {
        return toAjax(baseTyreService.updateBaseTyre(baseTyre));
    }

    /**
     * 删除轮胎
     */
    @PreAuthorize("@ss.hasPermi('basetyre:tyre:remove')")
    @Log(title = "轮胎", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        return toAjax(baseTyreService.deleteBaseTyreByIds(ids));
    }
}
