package com.ruoyi.basetyre.service.impl;

import java.util.List;

import com.ruoyi.common.core.domain.model.LoginUser;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.ServletUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.basetyre.mapper.BaseTyreMapper;
import com.ruoyi.basetyre.domain.BaseTyre;
import com.ruoyi.basetyre.service.IBaseTyreService;

/**
 * 轮胎Service业务层处理
 * 
 * @author Yangwl
 * @date 2023-02-15
 */
@Service
public class BaseTyreServiceImpl implements IBaseTyreService 
{
    @Autowired
    private BaseTyreMapper baseTyreMapper;

    /**
     * 查询轮胎
     * 
     * @param id 轮胎主键
     * @return 轮胎
     */
    @Override
    public BaseTyre selectBaseTyreById(String id)
    {
        return baseTyreMapper.selectBaseTyreById(id);
    }

    /**
     * 查询轮胎列表
     * 
     * @param baseTyre 轮胎
     * @return 轮胎
     */
    @Override
    public List<BaseTyre> selectBaseTyreList(BaseTyre baseTyre)
    {
        return baseTyreMapper.selectBaseTyreList(baseTyre);
    }

    /**
     * 新增轮胎
     * 
     * @param baseTyre 轮胎
     * @return 结果
     */
    @Override
    public int insertBaseTyre(BaseTyre baseTyre)
    {
        baseTyre.setCreateTime(DateUtils.getNowDate());
        LoginUser loginUser= SecurityUtils.getLoginUser();
        baseTyre.setCreateBy(loginUser.getUserId().toString());
        baseTyre.setCreateName(loginUser.getUsername());
        return baseTyreMapper.insertBaseTyre(baseTyre);
    }

    /**
     * 修改轮胎
     * 
     * @param baseTyre 轮胎
     * @return 结果
     */
    @Override
    public int updateBaseTyre(BaseTyre baseTyre)
    {
        return baseTyreMapper.updateBaseTyre(baseTyre);
    }

    /**
     * 批量删除轮胎
     * 
     * @param ids 需要删除的轮胎主键
     * @return 结果
     */
    @Override
    public int deleteBaseTyreByIds(String[] ids)
    {
        return baseTyreMapper.deleteBaseTyreByIds(ids);
    }

    /**
     * 删除轮胎信息
     * 
     * @param id 轮胎主键
     * @return 结果
     */
    @Override
    public int deleteBaseTyreById(String id)
    {
        return baseTyreMapper.deleteBaseTyreById(id);
    }
}
